Documentation
¶
Index ¶
- Constants
- Variables
- type APIs
- type EC2InstanceMetadataCache
- func (cache *EC2InstanceMetadataCache) AllocAllIPAddress(eniID string) error
- func (cache *EC2InstanceMetadataCache) AllocENI(useCustomCfg bool, sg []*string, subnet string) (string, error)
- func (cache *EC2InstanceMetadataCache) AllocIPAddress(eniID string) error
- func (cache *EC2InstanceMetadataCache) AllocIPAddresses(eniID string, numIPs int64) error
- func (cache *EC2InstanceMetadataCache) DescribeENI(eniID string) ([]*ec2.NetworkInterfacePrivateIpAddress, *string, error)
- func (cache *EC2InstanceMetadataCache) FreeENI(eniName string) error
- func (cache *EC2InstanceMetadataCache) GetAttachedENIs() (eniList []ENIMetadata, err error)
- func (cache *EC2InstanceMetadataCache) GetENILimit() (int, error)
- func (cache *EC2InstanceMetadataCache) GetENIipLimit() (int64, error)
- func (cache *EC2InstanceMetadataCache) GetLocalIPv4() string
- func (cache *EC2InstanceMetadataCache) GetPrimaryENI() string
- func (cache *EC2InstanceMetadataCache) GetPrimaryENImac() string
- func (cache *EC2InstanceMetadataCache) GetVPCIPv4CIDR() string
- type ENIMetadata
Constants ¶
const (
// UnknownInstanceType indicates that the instance type is not yet supported
UnknownInstanceType = "vpc ip resource(eni ip limit): unknown instance type"
)
Variables ¶
var InstanceENIsAvailable = map[string]int{}/* 140 elements not displayed */
InstanceENIsAvailable contains a mapping of instance types to the number of ENIs available which is described at https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-eni.html#AvailableIpPerENI
var InstanceIPsAvailable = map[string]int64{}/* 140 elements not displayed */
InstanceIPsAvailable contains a mapping of instance types to the number of IPs per ENI https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-eni.html#AvailableIpPerENI
Functions ¶
This section is empty.
Types ¶
type APIs ¶
type APIs interface {
// AllocENI creates an eni and attaches it to instance
AllocENI(useCustomCfg bool, sg []*string, subnet string) (eni string, err error)
// FreeENI detaches eni interface and deletes it
FreeENI(eniName string) error
// GetAttachedENIs retrieves eni information from instance metadata service
GetAttachedENIs() (eniList []ENIMetadata, err error)
// DescribeENI returns the IPv4 addresses of eni interface and eni attachment id
DescribeENI(eniID string) (addrList []*ec2.NetworkInterfacePrivateIpAddress, attachemdID *string, err error)
// AllocIPAddress allocates an ip address for an eni
AllocIPAddress(eniID string) error
// AllocAllIPAddress allocates all ip addresses available on an eni
AllocAllIPAddress(eniID string) error
// Allocate alloactes numIPs of IP address on a eni
AllocIPAddresses(eniID string, numIPs int64) error
// GetVPCIPv4CIDR returns vpc's cidr
GetVPCIPv4CIDR() string
// GetLocalIPv4 returns the primary IP address on the primary eni interface
GetLocalIPv4() string
// GetPrimaryENI returns the primary eni
GetPrimaryENI() string
// GetENIipLimit returns the number IP address can be allocated on a ENI
GetENIipLimit() (int64, error)
// GetENILimit returns the number of enis can be attached to an instance
GetENILimit() (int, error)
// GetPrimaryENImac returns the mac address of the primary eni
GetPrimaryENImac() string
}
APIs defines interfaces calls for adding/getting/deleting ENIs/secondary IPs. The APIs are not thread-safe.
type EC2InstanceMetadataCache ¶
type EC2InstanceMetadataCache struct {
// contains filtered or unexported fields
}
EC2InstanceMetadataCache caches instance metadata
func (*EC2InstanceMetadataCache) AllocAllIPAddress ¶
func (cache *EC2InstanceMetadataCache) AllocAllIPAddress(eniID string) error
AllocAllIPAddress allocates all IP addresses available on eni
func (*EC2InstanceMetadataCache) AllocENI ¶
func (cache *EC2InstanceMetadataCache) AllocENI(useCustomCfg bool, sg []*string, subnet string) (string, error)
AllocENI creates an eni and attach it to the instance returns: newly created eni id
func (*EC2InstanceMetadataCache) AllocIPAddress ¶
func (cache *EC2InstanceMetadataCache) AllocIPAddress(eniID string) error
AllocIPAddress allocates an IP address for an ENI
func (*EC2InstanceMetadataCache) AllocIPAddresses ¶ added in v1.1.0
func (cache *EC2InstanceMetadataCache) AllocIPAddresses(eniID string, numIPs int64) error
Allocate alloactes numIPs of IP address on a eni
func (*EC2InstanceMetadataCache) DescribeENI ¶
func (cache *EC2InstanceMetadataCache) DescribeENI(eniID string) ([]*ec2.NetworkInterfacePrivateIpAddress, *string, error)
DescribeENI returns the IPv4 addresses of interface and the attachment id return: private IP address, attachment id, error
func (*EC2InstanceMetadataCache) FreeENI ¶
func (cache *EC2InstanceMetadataCache) FreeENI(eniName string) error
FreeENI detachs ENI interface and delete ENI interface
func (*EC2InstanceMetadataCache) GetAttachedENIs ¶
func (cache *EC2InstanceMetadataCache) GetAttachedENIs() (eniList []ENIMetadata, err error)
GetAttachedENIs retrieves ENI information from meta data service
func (*EC2InstanceMetadataCache) GetENILimit ¶
func (cache *EC2InstanceMetadataCache) GetENILimit() (int, error)
GetENILimit returns the number of enis can be attached to an instance
func (*EC2InstanceMetadataCache) GetENIipLimit ¶
func (cache *EC2InstanceMetadataCache) GetENIipLimit() (int64, error)
GetENIipLimit return IP address limit per ENI based on EC2 instance type
func (*EC2InstanceMetadataCache) GetLocalIPv4 ¶
func (cache *EC2InstanceMetadataCache) GetLocalIPv4() string
GetLocalIPv4 returns the primary IP address on the primary interface
func (*EC2InstanceMetadataCache) GetPrimaryENI ¶
func (cache *EC2InstanceMetadataCache) GetPrimaryENI() string
GetPrimaryENI returns the primary ENI
func (*EC2InstanceMetadataCache) GetPrimaryENImac ¶ added in v1.2.1
func (cache *EC2InstanceMetadataCache) GetPrimaryENImac() string
GetPrimaryENIMAC returns the mac address of primary eni
func (*EC2InstanceMetadataCache) GetVPCIPv4CIDR ¶
func (cache *EC2InstanceMetadataCache) GetVPCIPv4CIDR() string
GetVPCIPv4CIDR returns VPC CIDR
type ENIMetadata ¶
type ENIMetadata struct {
// ENIID is the id of network interface
ENIID string
// MAC is the mac address of network interface
MAC string
// DeviceNumber is the device number of network interface
DeviceNumber int64 // 0 means it is primary interface
// SubnetIPv4CIDR is the ipv4 cider of network interface
SubnetIPv4CIDR string
// The ip addresses allocated for the network interface
LocalIPv4s []string
}
ENIMetadata contains ENI information retrieved from EC2 meta data service